#ifndef _PluginMap_h
#define _PluginMap_h


#include "Reaper.h"

#define NUM_OF_PLUGIN_MAPS 12
#define NUM_OF_PLUGIN_PARAMETERS 48
#define NUM_OF_ICON_MAPS 32


// plugin info and parameter mappings, 0 = null plugin containing empty maps
struct pluginIconMap{
  char            name[NAME_LENGTH+1];                  // plugin name, used for identification 
  int             iconIndex;                          // icon display index
};
typedef struct pluginIconMap PluginIconMap;


PluginIconMap iconMap[NUM_OF_ICON_MAPS]=
  {
    {"ADA Tapped Delay",24},
    {"AKG BX 20",15},
    {"AMS RMX16",17},
    {"API Channel Strip",9},
    {"Big Muff",39},
    {"Bluesbreaker",14},
    {"Boss Chorus",20},
    {"Cooper Time Cube",8},
    {"Dimension D",4},
    {"EMT 140",6},
    {"EMT 250",13},
    {"EP-34 Tape Echo",7},
    {"Fairchild 660",30},
    {"Fairchild 670",27},
    {"LA-2A Silver",21},
    {"Lexicon 224",5},
    {"Manley Variable Mu",16},
    {"Massive Passive",12},
    {"MXR Flanger",1},
    {"Plexi Super Lead",26},
    {"Pultec EQP-1A",11},
    {"Pultec HLF-3C",10},
    {"Pultec MEQ-5",29},
    {"Raw",40},
    {"Silver Jubilee",25},
    {"Space Echo",18},
    {"SPL TwinTube",2},
    {"SPL Vitalizer MK2",22},
    {"SSL Bus Compressor",19},
    {"Transient Designer",3},
    {"Tube screamer",41},
    {"UA 1176 Rev A",23}
  };

// struct containing parameter mapping
struct parameterData{
  char  name[NAME_LENGTH+1];                            // parameter long name
  int   number;                                       // parameter number
  bool  map;                                          // boolean indicating if map is present for this parameter (index)
  float   minValue;                                     // minimum map
  float   maxValue;                                     // maximum map
  int     precision;                                  // number of decimal places to display
  char  unit[4];                                      // unit containing leading space if required
  int   stepCount;                                    // step count, 0 if continuous
  int   imageOffset=10;                               // offset for userImages control on 4DSystems display
};
typedef struct parameterData ParameterData;

// plugin info and parameter mappings, index 0 = no map
struct pluginData{
  int             id;                                 // plugin id
  char            name[NAME_LENGTH+1];                  // plugin name, used for identification 
  int             iconIndex;                          // icon display index
  int             parameterCount;                     // number of parameters
  ParameterData   parameter[NUM_OF_PLUGIN_PARAMETERS];    // array with parameters
};
typedef struct pluginData PluginData;

PluginData pluginMap[NUM_OF_PLUGIN_MAPS]=
  { 
    0,"EMPTY",0,0,
      {
        {"", 1,0,1,100,0,"   ",0}
      },
    1,"Lexicon 224",5,27,
      {
        {"Program"      ,1,0,1,100,0,"   ",0,10},
        {"Bass"         ,2,0,1,100,0,"   ",0,10},
        {"Mid"          ,3,0,1,100,0,"   ",0,10},
        {"Crossover"    ,4,0,1,100,0,"   ",0,10},
        {"Treble Decay" ,5,0,1,100,0,"   ",0,10},
        {"Depth"        ,6,0,1,100,0,"   ",0,10},
        {"Predelay"     ,7,0,1,100,0,"   ",0,10},
        {"Diffusion"    ,8,0,1,100,0,"   ",0,10},
        {"IMMED"        ,9,0,1,100,0,"   ",0,10},
        {"Sys Noise"    ,10,0,1,100,0,"   ",0,10},
        {"Rear Outs"    ,11,0,1,100,0,"   ",0,10},
        {"Mix"          ,12,0,1,100,0,"   ",0,10},
        {"Wet Solo"     ,13,0,1,100,0,"   ",0,10},
        {"Mode Enh"     ,14,0,1,100,0,"   ",0,10},
        {"Enh -/+"      ,15,0,1,100,0,"   ",0,10},
        {"Pitch -/+"    ,16,0,1,100,0,"   ",0,10},
        {"Decay Opt"    ,17,0,1,100,0,"   ",0,10},
        {"Opt -/+"      ,18,0,1,100,0,"   ",0,10},
        {"In Gain L"    ,19,0,1,100,0,"   ",0,10},
        {"In Gain R"    ,20,0,1,100,0,"   ",0,10},
        {"Out Lvl L"    ,21,0,1,100,0,"   ",0,10},
        {"Out Lvl R"    ,22,0,1,100,0,"   ",0,10},
        {"Bug Fixes"    ,23,0,1,100,0,"   ",0,10},
        {"Link"         ,24,0,1,100,0,"   ",0,10},
        {"Power"        ,25,0,1,100,0,"   ",0,10},
        {"Bypass"       ,26,0,1,100,0,"   ",0,10},
        {"Wet"          ,27,0,1,100,0,"   ",0,10}
      },
    2,"Cooper Time Cube",8,17,
      {
        {"TempSync"   ,1,0,1,100,0,"   ",0,10},
        {"Send"   ,2,0,1,100,0,"   ",0,10},
        {"Gain"   ,3,0,1,100,0,"   ",0,10},
        {"Coils"    ,4,0,1,100,0,"   ",0,10},
        {"Color"    ,5,0,1,100,0,"   ",0,10},
        {"HPF"    ,6,0,1,100,0,"   ",0,10},
        {"Treble"   ,7,0,1,100,0,"   ",0,10},
        {"Bass"   ,8,0,1,100,0,"   ",0,10},
        {"RateA"    ,9,0,1,100,0,"   ",0,10},
        {"RateB"    ,10,0,1,100,0,"   ",0,10},
        {"DecayA"   ,11,0,1,100,0,"   ",0,10},
        {"DecayB"   ,12,0,1,100,0,"   ",0,10},
        {"PanA"   ,13,0,1,100,0,"   ",0,10},
        {"PanB"   ,14,0,1,100,0,"   ",0,10},
        {"EchoVolA"   ,15,0,1,100,0,"   ",0,10},
        {"EchoVolB"   ,16,0,1,100,0,"   ",0,10},
        {"WetSolo"    ,17,0,1,100,0,"   ",0,10}
      },
    3,"Pultec EQP-1A",11,12,
      {
        {"Low Freq"     ,1,0,1,100,0,"   ",3,318},
        {"LF Boost"     ,2,0,1,100,0,"   ",0,10},
        {"LF Atten"     ,3,0,1,100,0,"   ",0,10},
        {"High Freq"    ,4,0,1,100,0,"   ",6,311},
        {"HF Boost"     ,5,0,1,100,0,"   ",0,10},
        {"HF Q"         ,6,0,1,100,0,"   ",0,10},
        {"HF Atten Freq",7,0,1,100,0,"   ",0,10},
        {"HF Atten"     ,8,0,1,100,0,"   ",0,10},
        {"Enable"       ,9,0,1,100,0,"   ",0,10},
        {"Output"       ,10,0,1,100,0,"   ",0,10},
        {"Bypass"       ,11,0,1,100,0,"   ",0,10},
        {"Wet"          ,12,0,1,100,0,"   ",0,10}
      },
    4,"MXR Flanger",0,14,
      {
        {"Effect"       ,1,0,1,100,0,"   ",1,5},
        {"Stereo Mode"  ,2,0,1,100,0,"   ",1,5},
        {"Manual Delay" ,3,0,1,100,0,"   ",0,10},
        {"Sweep Width"  ,4,0,1,100,0,"   ",0,10},
        {"Sweep Speed"  ,5,0,1,100,0,"   ",0,10},
        {"Mix"          ,6,0,1,100,0,"   ",0,10},
        {"Regeneration" ,7,0,1,100,0,"   ",0,10},
        {"Mono Sum"     ,8,0,1,100,0,"   ",1,5},
        {"Phase Invert" ,9,0,1,100,0,"   ",1,5},
        {"LFO Reset"    ,10,0,1,100,0,"   ",1,5},
        {"Sync"         ,11,0,1,100,0,"   ",1,5},
        {"Power"        ,12,0,1,100,0,"   ",1,3},
        {"Bypass"       ,13,0,1,100,0,"   ",1,5},
        {"Wet"          ,14,0,1,100,0,"   ",0,10}
      },
    5,"EMT 140",6,20,
      {
        {"Plate"    ,1,0,1,100,0,"   ",2,7},
        {"DampA"    ,2,0,1,100,0,"   ",0,10},
        {"DampB"    ,3,0,1,100,0,"   ",0,10},
        {"DampC"    ,4,0,1,100,0,"   ",0,10},
        {"EQ"       ,5,0,1,100,0,"   ",0,10},
        {"LFreq"    ,6,0,1,100,0,"   ",0,10},
        {"LGain"    ,7,0,1,100,0,"   ",0,10},
        {"HFreq"    ,8,0,1,100,0,"   ",0,10},
        {"HGain"    ,9,0,1,100,0,"   ",0,10},
        {"PreDly"   ,10,0,1,100,0,"   ",0,10},
        {"ModRate"  ,11,0,1,100,0,"   ",0,10},
        {"ModDepth" ,12,0,1,100,0,"   ",0,10},
        {"Width"    ,13,0,1,100,0,"   ",0,10},
        {"WetSolo"  ,14,0,1,100,0,"   ",0,10},
        {"Mix"      ,15,0,1,100,0,"   ",0,10},
        {"LowCut"   ,16,0,1,100,0,"   ",0,10},
        {"Bal"      ,17,0,1,100,0,"   ",0,10},
        {"Power"    ,18,0,1,100,0,"   ",1,3},
        {"Bypass"   ,19,0,1,100,0,"   ",0,10},
        {"Wet"      ,20,0,1,100,0,"   ",0,10}
      },
    6,"Transient Designer",3,6,
      {
        {"Attack" ,1,1,-15,15,1," dB",0,659},
        {"Sustain",2,1,-24,24,1," dB",0,659},
        {"Gain"   ,3,0,1,100,0,"   ",0,659},
        {"Power"  ,4,0,1,100,0,"   ",1,3},
        {"Bypass" ,5,0,1,100,0,"   ",1,5},
        {"Wet"    ,6,0,1,100,0,"   ",0,10}
      },
    7,"SPL TwinTube",2,9,
      {
        {"Preset" ,1,0,1,100,0,"   ",3,354},
        {"Har On" ,2,0,1,100,0,"   ",1,5},
        {"Sat On" ,3,0,1,100,0,"   ",1,5},
        {"Freq"   ,4,0,1,100,0,"   ",3,350},
        {"Har"    ,5,1,0,20,1,"   ",0,659},
        {"Sat"    ,6,1,0,20,1,"   ",0,659},
        {"Output" ,7,0,1,100,0,"   ",0,659},
        {"Bypass" ,8,0,1,100,0,"   ",1,5},
        {"Wet"    ,9,0,1,100,0,"   ",0,10}
      },
    8,"Bluesbreaker",14,27,
      {
        {"Input"    ,1,0,1,100,0,"   ",11,322},
        {"Loud 1"   ,2,0,1,100,0,"   ",0,358},
        {"Loud 2"   ,3,0,1,100,0,"   ",0,358},
        {"Bass"     ,4,0,1,100,0,"   ",0,358},
        {"Middle"   ,5,0,1,100,0,"   ",0,358},
        {"Treble"   ,6,0,1,100,0,"   ",0,358},
        {"Presence" ,7,0,1,100,0,"   ",0,358},
        {"Inten."   ,8,0,1,100,0,"   ",0,358},
        {"Speed"    ,9,0,1,100,0,"   ",0,358},
        {"Out Vol"  ,10,0,1,100,0,"   ",0,358},
        {"Mic"      ,11,0,1,100,0,"   ",3,963},
        {"Level 1"  ,12,0,1,100,0,"   ",0,358},
        {"Level 2"  ,13,0,1,100,0,"   ",0,358},
        {"Level 3"  ,14,0,1,100,0,"   ",0,358},
        {"Level 4"  ,15,0,1,100,0,"   ",0,358},
        {"Pan 1"    ,16,0,1,100,0,"   ",0,358},
        {"Pan 2"    ,17,0,1,100,0,"   ",0,358},
        {"Pan 3"    ,18,0,1,100,0,"   ",0,358},
        {"Pan 4"    ,19,0,1,100,0,"   ",0,358},
        {"In 1"     ,20,0,1,100,0,"   ",1,5},
        {"In 2"     ,21,0,1,100,0,"   ",1,5},
        {"In 3"     ,22,0,1,100,0,"   ",1,5},
        {"In 4"     ,23,0,1,100,0,"   ",1,5},
        {"View"     ,24,0,1,100,0,"   ",1,5},
        {"Mode"     ,25,0,1,100,0,"   ",1,1},
        {"Bypass"   ,26,0,1,100,0,"   ",1,5},
        {"Wet"      ,27,0,1,100,0,"   ",0,10}
      },
    9,"Dimension D",0,5,
      {
        {"Mod Mode"   ,1,0,1,100,0,"   ",15,334},
        {"Input Mode" ,2,0,1,100,0,"   ",1,5},
        {"Power"      ,3,0,1,100,0,"   ",1,3},
        {"Bypass"     ,4,0,1,100,0,"   ",1,5},
        {"Wet"        ,5,0,1,100,0,"   ",0,10}
      },
    10,"Plexi Super Lead",26,24,
      {
        {"Presence"   ,1,0,1,100,0,"   ",0,358},
        {"Bass"       ,2,0,1,100,0,"   ",0,358},
        {"Middle"     ,3,0,1,100,0,"   ",0,358},
        {"Treble"     ,4,0,1,100,0,"   ",0,358},
        {"Vol 1"      ,5,0,1,100,0,"   ",0,358},
        {"Vol 2"      ,6,0,1,100,0,"   ",0,358},
        {"Input"      ,7,0,1,100,0,"   ",11,967},
        {"Mic"        ,8,0,1,100,0,"   ",3,963},
        {"Level 1"    ,9,0,1,100,0,"   ",0,10},
        {"Pan 1"      ,10,0,1,100,0,"   ",0,10},
        {"Level 2"    ,11,0,1,100,0,"   ",0,10},
        {"Pan 2"      ,12,0,1,100,0,"   ",0,10},
        {"Level 3"    ,13,0,1,100,0,"   ",0,10},
        {"Pan 3"      ,14,0,1,100,0,"   ",0,10},
        {"High"       ,15,0,1,100,0,"   ",0,10},
        {"Low"        ,16,0,1,100,0,"   ",0,10},
        {"Out Vol"    ,17,0,1,100,0,"   ",0,10},
        {"Solo 1"     ,18,0,1,100,0,"   ",1,3},
        {"Solo 2"     ,19,0,1,100,0,"   ",1,3},
        {"Solo 3"     ,20,0,1,100,0,"   ",1,3},
        {"View"       ,21,0,1,100,0,"   ",1,5},
        {"Mode"       ,22,0,1,100,0,"   ",1,1},
        {"Bypass"     ,23,0,1,100,0,"   ",1,5},
        {"Wet"        ,24,0,1,100,0,"   ",0,10}
      },
    11,"Silver Jubilee",25,31,
      {
        {"Presence"   ,1,0,1,100,0,"   ",0,979},
        {"Bass"       ,2,0,1,100,0,"   ",0,979},
        {"Middle"     ,3,0,1,100,0,"   ",0,979},
        {"Treble"     ,4,0,1,100,0,"   ",0,979},
        {"Gain"       ,5,0,1,100,0,"   ",0,979},
        {"Output"     ,6,0,1,100,0,"   ",0,979},
        {"Lead"       ,7,0,1,100,0,"   ",0,979},
        {"Rhythm"     ,8,0,1,100,0,"   ",1,5},
        {"Channel"    ,9,0,1,100,0,"   ",1,5},
        {"Output"     ,10,0,1,100,0,"   ",1,5},
        {"Gate"       ,11,0,1,100,0,"   ",0,979},
        {"Out Vol"    ,12,0,1,100,0,"   ",0,979},
        {"Mic"        ,13,0,1,100,0,"   ",2,960},
        {"Level 1"    ,14,0,1,100,0,"   ",0,10},
        {"Level 2"    ,15,0,1,100,0,"   ",0,10},
        {"Level 3"    ,16,0,1,100,0,"   ",0,10},
        {"Level 4"    ,17,0,1,100,0,"   ",0,10},
        {"Pan 1"      ,18,0,1,100,0,"   ",0,10},
        {"Pan 2"      ,19,0,1,100,0,"   ",0,10},
        {"Pan 3"      ,20,0,1,100,0,"   ",0,10},
        {"Pan 4"      ,21,0,1,100,0,"   ",0,10},
        {"In 1"       ,22,0,1,100,0,"   ",1,5},
        {"In 2"       ,23,0,1,100,0,"   ",1,5},
        {"In 3"       ,24,0,1,100,0,"   ",1,5},
        {"In 4"       ,25,0,1,100,0,"   ",1,5},
        {"Delay"      ,26,0,1,100,0,"   ",0,10},
        {"Feedback"   ,27,0,1,100,0,"   ",0,10},
        {"View"       ,28,0,1,100,0,"   ",1,5},
        {"Mode"       ,29,0,1,100,0,"   ",1,1},
        {"Bypass"     ,30,0,1,100,0,"   ",1,5},
        {"Wet"        ,31,0,1,100,0,"   ",0,10}
      }
  };


#endif
