
#include <OSCBundle.h>

#ifndef _Reaper_h
#define _Reaper_h


#define NUM_OF_TRACKS     24    // number of tracks in a bank = number of tracks Reaper will send
#define NUM_OF_PARAMETERS 48    // number of effect/instrument parameters in parameter bank = number of fx parameters Reaper will send
#define NUM_OF_SENDS      4     // number of sends, linked to Reaper OSC config = the number of sends Reaper will send.
#define NUM_OF_INSERTS    8     // number of fx inserts, linked to Reaper OSC config = the number of fx inserts Reaper will send.
#define NAME_LENGTH       18    // length of string for name strings
#define VALUE_LENGTH      16    // length of string for value strings

// struct containing OSC parameter data & values
struct oscParameter{
  char  name[NAME_LENGTH+1];                            // parameter long name
  int   number;                                       // parameter number
  char  valueStr[VALUE_LENGTH];                       // formatted string value e.g. '350Hz'
  float value;                                        // normalised value
};
typedef struct oscParameter OscParameter;

// struct for fx plugin
struct trackInsert{
  char  name[NAME_LENGTH+1];                            // plugin long name
  int   number;                                       // plugin number
  bool  bypass;                                       // bypass status
  char  mixStr[VALUE_LENGTH];                         // mix string    
  float mix;                                          // normalised mix
  //OscParameter parameter[NUM_OF_PARAMETERS];        // plugin parameters
};
typedef struct trackInsert TrackInsert;

// track send parameters
struct trackSend{
  char  name[NAME_LENGTH+1];                            // send long name
  int   number;                                       // send number
  char  volumeStr[VALUE_LENGTH];                      // volume string    
  float volume;                                       // normalised volume
  char  panStr[VALUE_LENGTH];                         // panning string    
  float pan;                                          // normalised panning
};
typedef struct trackSend TrackSend;

// struct containing Reaper track info & data
struct track{
  char        name[NAME_LENGTH+1];                      // track name
  int         number;                                 // track number
  char        volumeStr[VALUE_LENGTH];                // volume string    
  float       volume;                                 // normalised volume
  char        panStr[VALUE_LENGTH];                   // panning string    
  float       pan;                                    // normalised panning
  bool        rec;                                    // record arm
  bool        mute;                                   // track mute
  bool        solo;                                   // track solo
  bool        monitor;                                // track monitor
  TrackSend   send[NUM_OF_SENDS];                     // track sends
  TrackInsert insert[NUM_OF_INSERTS];                 // track effects/instrument plugins
};
typedef struct track Track;


// ***** MAIN CLASS ****
class Reaper{
  public:
    Reaper();
    Track         track[NUM_OF_TRACKS];                   // array with all track data
    Track         selectedTrack;                          // struct with data for selected track
    TrackInsert   selectedInsert;                         // struct with data for selected insert, used to keep track of insert context
    OscParameter  insertParameter[NUM_OF_PARAMETERS];     // array with parameters of the selected insert/fx/plugin
    int           selectedParameterBank=0;                // index of selected parameter bank
    int           selectedParameter=0;                    // index of selected insert parameter
    float         trackVuL=0;                             // vu meter for selected track
    float         trackVuR=0;                             // vu meter for selected track
    float         masterVuL=0;                            // vu meter for master
    float         masterVuR=0;                            // vu meter for master
    char          masterVolumeStr[VALUE_LENGTH];          // volume string    
    float         masterVolume;                           // normalised volume
    char          masterPanStr[VALUE_LENGTH];             // panning string    
    float         masterPan;                              // normalised panning
    TrackSend     masterSend[NUM_OF_SENDS];               // master sends
    char          beatStr[VALUE_LENGTH];                  // beat string
    int           beat;                                   // current beat
    int           measure;                                // current measure
    int           fraction;                               // current fraction
    float         tempo;                                  // tempo as float value
  private:
    void          _init();
    void          _initTrack(Track *track);
    void          _initInsert(TrackInsert *insert);
    void          _initOscParameter(OscParameter *parameter);
};

#endif
